@@ -1,4 +1,6 @@
 import asyncio
+import traceback
+from logging import getLogger
 from typing import Any, Callable, Optional
 
 from tornado.iostream import StreamClosedError
@@ -11,6 +13,8 @@ __all__ = [
     'default_error_handler',
 ]
 
+logging = getLogger('CATS')
+
 Middleware = Callable[[Handler], Optional[Any]]
 
 
@@ -30,6 +34,7 @@ async def default_error_handler(handler: Handler):
             'message': 'Request timeout',
         }, status=503)
     except Exception as err:
+        logging.debug(traceback.format_exc())
         return Action({
             'error': err.__class__.__name__,
             'message': str(err),
